searchData={"items":[{"type":"module","title":"Criterion","doc":"A frame work to write unit tests as a list of steps. It can be used to write tests BDD style.","ref":"Criterion.html"},{"type":"module","title":"Usage - Criterion","doc":"1. Define a feature using `feature/2` macro\n2. Define scenarios under the feature using the `scenario/3` macro.\n2. Inside each scenario, define steps using the `step/3` macro.\n3. Steps can be either plain steps, steps with context variables or shared step\n4. Shared steps can be defined using `defstep/4` macro","ref":"Criterion.html#module-usage"},{"type":"module","title":"Example - Criterion","doc":"","ref":"Criterion.html#module-example"},{"type":"module","title":"Shared steps - Criterion","doc":"```elixir\ndefmodule Criterion.SharedSteps do\n  import Criterion\n\n  defstep \"Given a number\", _context, args do\n    min = args[:min] || 0\n    %{number: min + :rand.uniform(100)}\n  end\nend\n```","ref":"Criterion.html#module-shared-steps"},{"type":"module","title":"Test - Criterion","doc":"```elixir\ndefmodule CriterionTest do\n  use ExUnit.Case\n  import Criterion\n  alias Criterion.SharedSteps\n\n  feature \"Math\" do\n    scenario \"Square\" do\n      step \"Given a number\", from: SharedSteps, where: [min: 2]\n\n      step \"When the number is multiplied by it self\", %{number: number} do\n        result = number * number\n        %{result: result}\n      end\n\n      step \"Then the result is greater than the number\", %{result: result, number: number} do\n        assert result > number\n      end\n    end\n  end\nend\n```","ref":"Criterion.html#module-test"},{"type":"macro","title":"Criterion.defstep/4","doc":"","ref":"Criterion.html#defstep/4"},{"type":"macro","title":"Criterion.feature/2","doc":"","ref":"Criterion.html#feature/2"},{"type":"macro","title":"Criterion.scenario/2","doc":"","ref":"Criterion.html#scenario/2"},{"type":"task","title":"mix criterion.gen.features","doc":"This Mix task scans the project for tests written using the `Criterion` module and generates\ncorresponding feature files in *Gherkin* syntax.","ref":"Mix.Tasks.Criterion.Gen.Features.html"},{"type":"task","title":"Usage - mix criterion.gen.features","doc":"```\nmix criterion.gen.features --dir  \n```","ref":"Mix.Tasks.Criterion.Gen.Features.html#module-usage"},{"type":"task","title":"Options - mix criterion.gen.features","doc":"- `--dir` - specify the directory to read test files from. default is `test`\n- `--file` - to generate feature files for a list of test files\n- `--output` - specify the directory to generate feature files in. default is `test/features`\n\nThe task will create the specified directory (default is `features`) and generate a `.feature` file for each test file\nin your project, converting the Criterion tests into Gherkin syntax.","ref":"Mix.Tasks.Criterion.Gen.Features.html#module-options"},{"type":"function","title":"Mix.Tasks.Criterion.Gen.Features.run/1","doc":"","ref":"Mix.Tasks.Criterion.Gen.Features.html#run/1"},{"type":"task","title":"mix criterion.gen.tests","doc":"This Mix task reads Gherkin feature files and generates corresponding test files using the Criterion module.","ref":"Mix.Tasks.Criterion.Gen.Tests.html"},{"type":"task","title":"Usage - mix criterion.gen.tests","doc":"```\nmix criterion.gen.tests\n```","ref":"Mix.Tasks.Criterion.Gen.Tests.html#module-usage"},{"type":"task","title":"Options - mix criterion.gen.tests","doc":"- `--dir` - specify the directory to read feature files from. default is `test/features`\n- `--file` - to generate test for a list of files\n- `--output` - specify the directory to generate the test files in. default is `test/features`","ref":"Mix.Tasks.Criterion.Gen.Tests.html#module-options"},{"type":"function","title":"Mix.Tasks.Criterion.Gen.Tests.run/1","doc":"","ref":"Mix.Tasks.Criterion.Gen.Tests.html#run/1"},{"type":"extras","title":"Criterion","doc":"# Criterion\n\nA library to write ExUnit tests BDD style","ref":"readme.html"},{"type":"extras","title":"Installation - Criterion","doc":"The package can be installed\nby adding `criterion` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:criterion, \"~> 0.1.0\", only: [:test]}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Criterion","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Shared steps - Criterion","doc":"```elixir\ndefmodule Criterion.SharedSteps do\n  import Criterion\n\n  defstep \"Given a number\", _context, args do\n    min = args[:min] || 0\n    %{number: min + :rand.uniform(100)}\n  end\nend\n```","ref":"readme.html#shared-steps"},{"type":"extras","title":"Test - Criterion","doc":"```elixir\ndefmodule CriterionTest do\n  use ExUnit.Case\n  import Criterion\n  alias Criterion.SharedSteps\n\n  feature \"Math\" do\n    scenario \"Square\" do\n      step \"Given a number\", from: SharedSteps, where: [min: 2]\n\n      step \"When the number is multiplied by it self\", %{number: number} do\n        result = number * number\n        %{result: result}\n      end\n\n      step \"Then the result is greater than the number\", %{result: result, number: number} do\n        assert result > number\n      end\n    end\n  end\nend\n```","ref":"readme.html#test"},{"type":"extras","title":"Generating feature files - Criterion","doc":"```\nmix criterion.gen.features\n```\n\n#### Options\n\n- `--dir` - specify the directory to read test files from. default is `test`\n- `--file` - to generate feature files for a list of test files\n- `--output` - specify the directory to generate feature files in. default is `test/features`","ref":"readme.html#generating-feature-files"},{"type":"extras","title":"Generating test files - Criterion","doc":"```\nmix criterion.gen.tests\n```\n\n#### Options\n\n- `--dir` - specify the directory to read feature files from. default is `test/features`\n- `--file` - to generate test for a list of files\n- `--output` - specify the directory to generate the test files in. default is `test/features`","ref":"readme.html#generating-test-files"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}